from datetime import datetime as dt, timedelta, date

from data_loader import es_premium_df, role_ids, translate_freq, segments, schools_names, date_column, events, non_assistent_teachers

import dash
import dash_core_components as dcc
import dash_html_components as html
from dash.dependencies import Input, Output

inputs = [
    dcc.DatePickerRange(
        #TODO: fix calendar layout
        id='date-picker-range',
        start_date=date.fromisoformat("2020-01-01"),
        end_date=dt.now().date()-timedelta(days=1),
        min_date_allowed=date.fromisoformat("2020-01-01"),
        max_date_allowed=dt.now().date(),
        initial_visible_month=date.fromisoformat("2020-01-01"),
        display_format='DD/MM/YY',
        style={'width': '400px'},
        className="padding-top-bot",
    ),
    dcc.Dropdown(
        id='school_select',
        options=[{'label': n,'value': n} for n in schools_names.keys()],
        # value="Agregado: Todas da base",
        value="Colégio Genius",
        style={'width': '300px'},
        placeholder="Escolha qual escola visualizar"
    ),
    dcc.Dropdown(
        id='role_select',
        options=[{'label': n, 'value': n} for n in ["professor", "aluno"]],
        value='professor',
        style={'width': '200px'},
        placeholder="Escolha um filtro de usuário"
    ),
    dcc.Dropdown(
        optionHeight=50,
        id='usage_lines_selector',
        options=[{'label': u[1], 'value': u[0]} for u in [(0, "Geral")]],
        value=[0],
        style={'width': '200px'},
        multi=True
    ),
    dcc.Loading(
        id="role_filters",
        style={'border-width': '15%'},
        type='circle'
    ),
    dcc.Dropdown(
        id='periodicity_select',
        options=[{'label': n, 'value': n} for n in ["semanal", "bi-semanal", "mensal"]],
        value='semanal',
        style={'width': '200px'},
        placeholder="Escolha um intervalo de tempo "
    ),
    dcc.Dropdown(
        id='segment_select',
        options=[{'label': n, 'value': n} for n in segments],
        value=["Fundamental 1", "Fundamental 2"],
        style={'width': '200px'},
        multi=True,
        placeholder="Escolha quais segmentos visulizar"
    ),
    dcc.Dropdown(
        id='event_select',
        options=[{'label': n, 'value': n} for n in events],
        value=["LOGIN"],
        style={'width': '200px'},
        multi=True,
        placeholder="Escolha quais segmentos visulizar"
    ),
]

chart_view = [
    dcc.Tabs(id="tabs", value='tab-1', children=[
        dcc.Tab(label='Gráfico', value='tab-1'),
        dcc.Tab(label='Detalhado', value='tab-2'),
    ]),
    html.Div(id='tabs-content')
]